@@ -455,7 +455,7 @@ def method_profiling(fn):
             ctx.service_name=fn.__name__
             ctx = start_interceptor(ctx)
             callback = fn(*args, **kwargs)
-            end_interceptor(ctx.thread_id)
+            end_interceptor(thread_id= ctx.thread_id)
         except Exception as e:
             logging.debug('WHATAP(@method_profiling): ' + str(e),
                           extra={'id': 'WA776'}, exc_info=True)
@@ -508,7 +508,7 @@ def batch_profiling(fn):
             ctx = start_interceptor(ctx)
             
             callback = fn(*args, **kwargs)
-            end_interceptor(ctx.thread_id)
+            end_interceptor(thread_id=ctx.thread_id)
         except Exception as e:
             logging.debug('WHATAP(@batch_profiling): ' + str(e),
                           extra={'id': 'WA777'}, exc_info=True)
