@@ -22,7 +22,7 @@ def interceptor(fn, task_name, *args, **kwargs):
         raise e
     finally:
         if ctx:
-            end_interceptor()
+            end_interceptor(ctx=ctx)
 
 def trace_handler(fn, start=False):
     def handler(func):
@@ -32,7 +32,7 @@ def trace_handler(fn, start=False):
             if not start and not ctx:
                 return fn(*args, **kwargs)
             if ctx and ctx.error_step:
-                end_interceptor()
+                end_interceptor(ctx=ctx)
                 raise Exception(ctx.error_step)
             callback = func(*args, **kwargs)
             return callback
