@@ -1,4 +1,4 @@
-import os
+import os, sys
 import random
 import threading
 import time
@@ -73,8 +73,8 @@ class TraceContextManager(object):
     
     @classmethod
     def getLocalContext(cls):
-        if not bool(cls.local.__dict__):
-            cls.local.context = None
+        # print('TraceContextManager.getLocalContext:', cls.getCurrentKey())
+        return cls.getContext(cls.getCurrentKey())
         
         return cls.local.context
     
@@ -83,15 +83,23 @@ class TraceContextManager(object):
         uuid1 = uuid.uuid1(TraceContextManager.node, TraceContextManager.clock_seq)
         key = (uuid1.int >> 64 & 0xffffffffffffffff) ^ (uuid1.int << 64 & 0xffffffffffffffff)
         return key
-    
+
     @classmethod
-    def start(cls, o, thread_id):
+    def getCurrentKey(cls):
+        thread_id = cls.getCurrentThreadId()
         pid = os.getpid()
         dout = DataOutputX()
         dout.writeInt(pid)
         dout.writeInt(0)
         din = DataInputX(dout.buffer.getvalue())
         key = din.readLong() + thread_id
+
+        return key
+
+    @classmethod
+    def start(cls, o):
+        key = cls.getCurrentKey()
+        print('TraceContextManager.start:', key)
         cls.local.context = o
         cls.entry.put(key, o)
 
@@ -110,7 +118,7 @@ class TraceContextManager(object):
     @classmethod
     def end(cls, key):
         cls.local.context = None
-        cls.entry.remove(key)
+        cls.entry.remove(str(key))
 
     @classmethod
     def getTxProfile(cls, n):
@@ -118,3 +126,13 @@ class TraceContextManager(object):
         if not ctx:
             return None
         return ctx.profile.getLastSteps(n)
+
+    @classmethod
+    def getCurrentThreadId(cls):
+        greenlet = sys.modules.get('greenlet')
+
+        if greenlet:
+            current = greenlet.getcurrent()
+            if current is not None and current.parent:
+                return id(current.parent)
+        return threading.get_ident()
\ No newline at end of file
